@@ -4,8 +4,10 @@ from __future__ import print_function
 
 import numpy as np
 
+from auto_editor.utils.types import split_num_str
+
 def combine_audio_motion(audioList, motionList, based, log):
-    # (audioList: np.ndarray, motionList: np.ndarray, based: str, log) -> np.ndarray:
+    # type: (np.ndarray, np.ndarray, str, Any) -> np.ndarray
 
     if(based == 'audio' or based == 'not_audio'):
         if(max(audioList) == 0):
@@ -61,7 +63,7 @@ def combine_segment(has_loud, segment, fps):
 
 
 def removeSmall(has_loud, lim, replace, with_):
-    # (has_loud: np.ndarray, lim: int, replace: bool, with_: bool) -> np.ndarray:
+    # type: (np.ndarray, int, int, int) -> np.ndarray
     startP = 0
     active = False
     for j, item in enumerate(has_loud):
@@ -81,44 +83,64 @@ def removeSmall(has_loud, lim, replace, with_):
     return has_loud
 
 
-def is_number(val):
-    return val.replace('.', '', 1).isdigit()
+def str_is_number(val):
+    # type: (str) -> bool
+    return val.replace('.', '', 1).replace('-', '', 1).isdigit()
 
-def setRange(has_loud, syntaxRange, fps, with_, log):
-    # (has_loud: np.ndarray, syntaxRange, fps: float, with_, log) -> np.ndarray:
 
-    def replace_variables_to_values(item):
-        if(is_number(item)):
+def str_starts_with_number(val):
+    # type: (str) -> bool
+    if(val.startswith('-')):
+        val = val[1:]
+    val = val.replace('.', '', 1)
+    return val[0].isdigit()
+
+
+def setRange(has_loud, range_syntax, fps, with_, log):
+    # type: (...) -> np.ndarray
+
+    def replace_variables_to_values(item, fps, log):
+        # type: (str, float | int, Any) -> int
+        if(str_is_number(item)):
             return int(item)
+        if(str_starts_with_number(item)):
+            value, unit = split_num_str(item, log.error)
+            if(unit in ['', 'f', 'frame', 'frames']):
+                if(isinstance(value, float)):
+                    log.error('float type cannot be used with frame unit')
+                return value
+            if(unit in ['s', 'sec', 'secs', 'second', 'seconds']):
+                return int(round(value * fps))
+            log.error('Unknown unit: {}'.format(unit))
         if(item == 'start'):
             return 0
         if(item == 'end'):
             return len(has_loud)
-        if(item.startswith('sec')):
-            log.error('Seconds unit not implemented in this function.')
-        log.error('Variable {} not avaiable in this context.'.format(item))
+        log.error('Variable {} not available.'.format(item))
 
-    def var_val_to_frames(num):
-        # (num) -> int:
-        num = replace_variables_to_values(num)
+    def var_val_to_frames(val, fps, log):
+        # type: (str, float | int, Any) -> int
+        num = replace_variables_to_values(val, fps, log)
         if(num < 0):
-            num = len(has_loud) - num
+            num += len(has_loud)
         return num
 
-    for item in syntaxRange:
-        pair = list(map(var_val_to_frames, item))
+    for item in range_syntax:
+        pair = []
+        for val in item:
+            pair.append(var_val_to_frames(val, fps, log))
         has_loud[pair[0]:pair[1]] = with_
     return has_loud
 
 
 def seconds_to_frames(value, fps):
-    # (int | str, float) -> int:
+    # type: (int | str, float) -> int
     if(isinstance(value, str)):
         return int(float(value) * fps)
     return value
 
 def cook(has_loud, minClip, minCut):
-    # (has_loud: np.ndarray, minClip: int, minCut: int) -> np.ndarray:
+    # type: (np.ndarray, int, int) -> np.ndarray
     has_loud = removeSmall(has_loud, minClip, replace=1, with_=0)
     has_loud = removeSmall(has_loud, minCut, replace=0, with_=1)
     return has_loud
@@ -127,7 +149,7 @@ def cook(has_loud, minClip, minCut):
 # Turn long silent/loud array to formatted chunk list.
 # Example: [True, True, True, False, False] => [[0, 3, 1], [3, 5, 0]]
 def chunkify(has_loud, has_loud_length=None):
-    # (np.ndarray, int) -> list:
+    # type: (np.ndarray, int | None) -> list[list[int]]
     if(has_loud_length is None):
         has_loud_length = len(has_loud)
 
@@ -142,7 +164,7 @@ def chunkify(has_loud, has_loud_length=None):
 
 
 def apply_frame_margin(has_loud, has_loud_length, frame_margin):
-    # (np.ndarray, int, int) -> np.ndarray:
+    # type: (np.ndarray, int, int) -> np.ndarray
     new = np.zeros((has_loud_length), dtype=np.uint8)
     for i in range(has_loud_length):
         start = int(max(0, i - frame_margin))
@@ -151,7 +173,7 @@ def apply_frame_margin(has_loud, has_loud_length, frame_margin):
     return new
 
 def apply_spacing_rules(has_loud, has_loud_length, minClip, minCut, speeds, fps, args, log):
-    # (has_loud: np.ndarray, speeds: list, fps: float, args, log) -> list:
+    # type: (...) -> list[list[int]]
     if(args.mark_as_loud != []):
         has_loud = setRange(has_loud, args.mark_as_loud, fps, 1, log)
 
@@ -174,7 +196,7 @@ def apply_spacing_rules(has_loud, has_loud_length, minClip, minCut, speeds, fps,
 
 
 def apply_basic_spacing(has_loud, fps, minClip, minCut, log):
-    # (has_loud: np.ndarray, fps: float, minClip: int, minCut: int, log) -> list:
+    # type: (np.ndarray, float, int, int, Any) -> list[list[int]]
     minClip = seconds_to_frames(minClip, fps)
     minCut = seconds_to_frames(minCut, fps)
 
@@ -183,7 +205,7 @@ def apply_basic_spacing(has_loud, fps, minClip, minCut, log):
 
 
 def merge(start_list, end_list):
-    # (start_list: np.ndarray, end_list: np.ndarray) -> np.ndarray:
+    # type: (np.ndarray, np.ndarray) -> np.ndarray
     merge = np.zeros((len(start_list)), dtype=np.bool_)
 
     startP = 0
@@ -197,7 +219,7 @@ def merge(start_list, end_list):
 
 
 def handleBoolExp(val, data, sampleRate, fps, log):
-    # (val: str, data, sampleRate, fps, log) -> list:
+    # type: (...) -> np.ndarray
     invert = False
 
     if('>' in val and '<' in val):
