@@ -11,13 +11,11 @@ from auto_editor.scipy.wavfile import read, write
 def convertAudio(ffmpeg, in_file, inp, out_file, codec, log):
     if(fnone(codec)):
         codec = inp.audio_streams[0]['codec']
-    if(codec == 'pcm_s16le' and out_file.endswith('.m4a')):
-        log.error('Codec: {} is not supported in the m4a container.'.format(codec))
 
     ffmpeg.run(['-i', in_file, '-acodec', codec, out_file])
 
 def handleAudio(ffmpeg, in_file, audioBit, samplerate, temp, log):
-    # () -> str:
+    # type: (...) -> str
     temp_file = os.path.join(temp, 'faAudio.wav')
 
     log.checkType(samplerate, 'samplerate', str)
