@@ -1,10 +1,14 @@
 '''subcommands/info.py'''
 
+from __future__ import print_function
+
 def info_options(parser):
     parser.add_argument('--include_vfr', action='store_true',
         help='skip information that is very slow to get.')
+    parser.add_argument('--ffmpeg_location', default=None,
+        help='point to your custom ffmpeg file.')
     parser.add_argument('--my_ffmpeg', action='store_true',
-        help='use your ffmpeg and other binaries instead of the ones packaged.')
+        help='use the ffmpeg on your PATH instead of the one packaged.')
     parser.add_argument('--help', '-h', action='store_true',
         help='print info about the program or an option and exit.')
     parser.add_argument('(input)', nargs='*',
@@ -18,13 +22,11 @@ def info(sys_args=None):
     import auto_editor
     import auto_editor.vanparse as vanparse
 
-    from auto_editor.usefulFunctions import cleanList, aspect_ratio
+    from auto_editor.utils.func import clean_list, aspect_ratio
     from auto_editor.utils.log import Log
 
     from auto_editor.ffwrapper import FFmpeg
 
-    dir_path = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
-
     parser = vanparse.ArgumentParser('info', auto_editor.version,
         description='Get basic information about media files.')
     parser = info_options(parser)
@@ -35,13 +37,14 @@ def info(sys_args=None):
     log = Log()
     args = parser.parse_args(sys_args, log, 'info')
 
-    ffmpeg = FFmpeg(dir_path, args.my_ffmpeg, False, log)
+    dir_path = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
+    ffmpeg = FFmpeg(dir_path, args.ffmpeg_location, args.my_ffmpeg, False, log)
 
     def aspect_str(w, h):
         w, h = aspect_ratio(int(w), int(h))
         if(w is None):
             return ''
-        return '{}:{}'.format(w, h)
+        return ' ({}:{})'.format(w, h)
 
     for file in args.input:
         text = ''
@@ -59,7 +62,9 @@ def info(sys_args=None):
             w = inp.video_streams[0]['width']
             h = inp.video_streams[0]['height']
 
-            text += ' - resolution: {}x{} ({})\n'.format(w, h, aspect_str(w, h))
+            if(w is not None and h is not None):
+                text += ' - resolution: {}x{}{}\n'.format(w, h, aspect_str(w, h))
+
             text += ' - video codec: {}\n'.format(inp.video_streams[0]['codec'])
             text += ' - video bitrate: {}\n'.format(inp.video_streams[0]['bitrate'])
 
@@ -85,7 +90,7 @@ def info(sys_args=None):
                 text = ''
                 fps_mode = ffmpeg.pipe(['-i', file, '-hide_banner', '-vf', 'vfrdet',
                     '-an', '-f', 'null', '-'])
-                fps_mode = cleanList(fps_mode.split('\n'), '\r\t')
+                fps_mode = clean_list(fps_mode.split('\n'), '\r\t')
                 fps_mode = fps_mode.pop()
 
                 if('VFR:' in fps_mode):
