@@ -1,10 +1,16 @@
 '''subcommands/levels.py'''
 
+from __future__ import print_function
+
 def levels_options(parser):
     parser.add_argument('--output_file', '--output', '-o', type=str,
         default='data.txt')
+    parser.add_argument('--track', type=int, default=0,
+        help='what audio/video track to get. If --kind is set to motion, track will look at video streams.')
+    parser.add_argument('--ffmpeg_location', default=None,
+        help='point to your custom ffmpeg file.')
     parser.add_argument('--my_ffmpeg', action='store_true',
-        help='use your ffmpeg and other binaries instead of the ones packaged.')
+        help='use the ffmpeg on your PATH instead of the one packaged.')
     parser.add_argument('--help', '-h', action='store_true',
         help='print info about the program or an option and exit.')
     parser.add_argument('(input)', nargs='*',
@@ -24,9 +30,7 @@ def levels(sys_args=None):
 
     from auto_editor.utils.log import Log
     from auto_editor.ffwrapper import FFmpeg
-    from auto_editor.wavfile import read
-
-    dir_path = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
+    from auto_editor.scipy.wavfile import read
 
     parser = vanparse.ArgumentParser('levels', auto_editor.version,
         description='Get loudness of audio over time.')
@@ -40,17 +44,22 @@ def levels(sys_args=None):
 
     args = parser.parse_args(sys_args, log, 'levels')
 
-    ffmpeg = FFmpeg(dir_path, args.my_ffmpeg, False, log)
+    dir_path = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
+    ffmpeg = FFmpeg(dir_path, args.ffmpeg_location, args.my_ffmpeg, False, log)
+
     inp = ffmpeg.file_info(args.input[0])
 
     fps = 30 if inp.fps is None else float(inp.fps)
 
+    if(args.track > len(inp.audio_streams)):
+        log.error('Audio track {} does not exist.'.format(args.track))
+
     # Split audio tracks into: 0.wav, 1.wav, etc.
     for t in range(len(inp.audio_streams)):
         ffmpeg.run(['-i', inp.path, '-ac', '2', '-map', '0:a:{}'.format(t),
             os.path.join(temp, '{}.wav'.format(t))])
 
-    sample_rate, audio_data = read(os.path.join(temp, '0.wav'))
+    sample_rate, audio_data = read(os.path.join(temp, '{}.wav'.format(args.track)))
     audio_sample_count = audio_data.shape[0]
 
     def get_max_volume(s):
@@ -59,7 +68,7 @@ def levels(sys_args=None):
     max_volume = get_max_volume(audio_data)
 
     samples_per_frame = sample_rate / fps
-    audio_frame_count = math.ceil(audio_sample_count / samples_per_frame)
+    audio_frame_count = int(math.ceil(audio_sample_count / samples_per_frame))
 
     with open(args.output_file, 'w') as out:
         for i in range(audio_frame_count):
