@@ -68,6 +68,19 @@ class FFprobe():
     def getSampleRate(self, file, track=0):
         return self._get(file, 'sample_rate', 'a', track)
 
+    def AudioBitRate(self, file):
+
+        def bitrate_format(num):
+            magnitude = 0
+            while abs(num) >= 1000:
+                magnitude += 1
+                num /= 1000.0
+            num = int(round(num))
+            return '%d%s' % (num, ['', 'k', 'm', 'g', 't', 'p'][magnitude])
+
+        exact_bitrate = self._get(file, 'bit_rate', 'a', 0)
+        return bitrate_format(int(exact_bitrate))
+
 
 def pipe_to_console(cmd):
     process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
@@ -95,8 +108,10 @@ def getRunner():
 
 
 def run_program(cmd):
+    no_open = '.' in cmd[0]
     cmd = getRunner() + cmd
-    if('.' in cmd[0]):
+
+    if(no_open):
         cmd += ['--no_open']
 
     returncode, stdout, stderr = pipe_to_console(cmd)
@@ -125,16 +140,15 @@ def fullInspect(fileName, *args):
                 from math import ceil
                 if(ceil(func(fileName) * 100) == expectedOutput * 100):
                     continue
-            print('Expected Value: {} {}'.format(expectedOutput, type(expectedOutput)))
-            print('Actual Value: {} {}'.format(func(fileName), type(func(fileName))))
-            raise Exception('Inspection Failed.')
+            raise Exception('Inspection Failed. Was {}, Expected {}.'.format(
+                expectedOutput, func(fileName)))
 
 
 class Tester():
     def __init__(self, args):
         self.passed_tests = 0
         self.failed_tests = 0
-        self.allowable_fails = 0
+        self.allowable_fails = 1
         self.args = args
 
     def run_test(self, name, func, description='', cleanup=None):
@@ -234,9 +248,51 @@ def test(sys_args=None):
         )
     tester.run_test('example_tests', example_tests)
 
+    # Issue #200
+    def url_test():
+        run_program(['https://github.com/WyattBlue/auto-editor/raw/master/example.mp4'])
+    tester.run_test('url_test', url_test)
+
+    # Issue #172
+    def bitrate_test():
+        run_program(['example.mp4', '--audio_bitrate', '50k'])
+        fullInspect(
+            'example_ALTERED.mp4',
+            [ffprobe.AudioBitRate, '50k'],
+        )
+    tester.run_test('bitrate_test', bitrate_test)
+
+    # Issue #184
+    def unit_tests():
+        run_program(['example.mp4', '--mark_as_loud', '20s,22sec', '25secs,26.5seconds'])
+        run_program(['example.mp4', '--sample_rate', '44100'])
+        run_program(['example.mp4', '--sample_rate', '44100 Hz'])
+        run_program(['example.mp4', '--sample_rate', '44.1 kHz'])
+        run_program(['example.mp4', '--silent_threshold', '4%'])
+    tester.run_test('unit_tests', unit_tests,
+        description='''
+        Make sure all units are working appropriately. That includes:
+         - Seconds units: s, sec, secs, second, seconds
+         - Frame units:   f, frame, frames
+         - Sample units:  Hz, kHz
+         - Percent:       %
+
+        ''')
+
+    def backwards_range_test():
+        run_program(['example.mp4', '--edit', 'none', '--cut_out', '-5secs,end'])
+    tester.run_test('backwards_range_test', backwards_range_test, description='''
+        Cut out the last 5 seconds of a media file by using negative number in the
+        range.
+        ''')
+
     def gif_test():
         run_program(['resources/man_on_green_screen.gif', '--edit', 'none'])
-    tester.run_test('gif_test', gif_test, description='run gif files', cleanup=clean_all)
+    tester.run_test('gif_test', gif_test, description='''
+        Feed auto-editor a gif file and make sure it can spit out a correctly formated
+        gif. No editing is requested.
+        ''',
+        cleanup=clean_all)
 
     def render_tests():
         run_program(['example.mp4', '--render', 'opencv'])
@@ -252,6 +308,9 @@ def test(sys_args=None):
         run_program(['example.mp4', '-m', '3'])
         run_program(['example.mp4', '--margin', '3'])
         run_program(['example.mp4', '-m', '0.3sec'])
+        run_program(['example.mp4', '-m', '6f'])
+        run_program(['example.mp4', '-m', '5 frames'])
+        run_program(['example.mp4', '-m', '0.4 seconds'])
     tester.run_test('margin_tests', margin_tests)
 
     def extension_tests():
