@@ -1,9 +1,13 @@
 '''utils/log.py'''
 
+from __future__ import print_function
+
 import sys
-from shutil import rmtree, get_terminal_size
+from shutil import rmtree
 from time import time, sleep
 
+from .func import term_size
+
 class Timer():
     def __init__(self, quiet=False):
         self.start_time = time()
@@ -39,20 +43,33 @@ class Log():
             try:
                 rmtree(self.temp)
                 self.debug('Removed Temp Directory.')
-            except PermissionError:
+            except Exception:
                 self.debug('Failed to delete temp dir.')
 
     def conwrite(self, message):
         if(not self.quiet):
-            buffer = get_terminal_size().columns - len(message) - 3
-            print('  ' + message + ' ' * buffer, end='\r', flush=True)
+            buffer = term_size().columns - len(message) - 3
+            try:
+                print('  ' + message + ' ' * buffer, end='\r', flush=True)
+            except TypeError:
+                print('  ' + message + ' ' * buffer, end='\r')
 
     def error(self, message):
         self.conwrite('')
         message = message.replace('\t', '    ')
         print('Error! {}'.format(message), file=sys.stderr)
         self.cleanup()
-        sys.exit(1)
+
+        from platform import system
+
+        if(system() == 'Linux'):
+            sys.exit(1)
+        else:
+            try:
+                sys.exit(1)
+            except SystemExit:
+                import os
+                os._exit(1)
 
     def bug(self, message, bug_type='bug report'):
         self.conwrite('')
