@@ -231,7 +231,7 @@ class ParseOptions():
 
             if(option is None):
                 # Unknown Option!
-                if(setting_inputs and not item.startswith('-')):
+                if(setting_inputs and (option_list != 'input' or (option_list == 'input' and not item.startswith('-')))):
                     # Option is actually an input file, like example.mp4
                     my_list.append(item)
                 else:
@@ -270,14 +270,8 @@ class ParseOptions():
                 elif(option['action'] == 'store_false'):
                     value = False
                 else:
-                    try:
-                        value = option['type'](nextItem)
-                    except Exception:
-                        typeName = option['type'].__name__
-                        log.error('Couldn\'t convert {} to {}'.format(
-                            nextItem, typeName))
+                    value = option['type'](nextItem)
 
-                    # Handle when the option value is not in choices list.
                     if(option['choices'] is not None and value not in option['choices']):
                         option_name = option['names'][0]
                         my_choices = ', '.join(option['choices'])
